diff -ur ircd-hybrid-6/include/channel.h ircd-hybrid-6+stats/include/channel.h
--- ircd-hybrid-6/include/channel.h	Wed Jul 18 16:58:44 2001
+++ ircd-hybrid-6+stats/include/channel.h	Thu Aug 23 04:35:25 2001
@@ -111,7 +111,8 @@
 extern void    set_channel_mode(struct Client *, struct Client *, 
                                 struct Channel *, int, char **);
 
-
+extern int total_hackops;
+extern int total_ignoreops;
 
 /* this should eliminate a lot of ifdef's in the main code... -orabidoo */
 #ifdef BAN_INFO
diff -ur ircd-hybrid-6/include/patchlevel.h ircd-hybrid-6+stats/include/patchlevel.h
--- ircd-hybrid-6/include/patchlevel.h	Thu Aug 23 03:52:59 2001
+++ ircd-hybrid-6+stats/include/patchlevel.h	Thu Aug 23 03:54:40 2001
@@ -17,5 +17,5 @@
  */
 
 #ifndef PATCHLEVEL
-#define PATCHLEVEL    "2.8/hybrid-6.2rc1"
+#define PATCHLEVEL    "2.8/hybrid-6.2rc1+stats"
 #endif
Only in ircd-hybrid-6/include: patchlevel.h.orig
diff -ur ircd-hybrid-6/src/channel.c ircd-hybrid-6+stats/src/channel.c
--- ircd-hybrid-6/src/channel.c	Fri Aug 10 06:59:14 2001
+++ ircd-hybrid-6+stats/src/channel.c	Thu Aug 23 04:38:30 2001
@@ -44,6 +44,9 @@
 #include <string.h>
 #include <stdlib.h>
 
+int total_hackops = 0;
+int total_ignoreops = 0;
+
 #ifdef NEED_SPLITCODE
 
 static void check_still_split();
@@ -3695,7 +3698,10 @@
     if(doesop)
       keep_our_modes = NO;
     if(haveops && !doesop)
+    {
       tstosend = oldts;
+      total_ignoreops++;
+    }
     else
       chptr->channelts = tstosend = newts;
 #endif      
@@ -3721,7 +3727,10 @@
       if(haveops)
         keep_new_modes = NO;
       if (doesop && !haveops)
+      {
+        total_hackops++;
         chptr->channelts = tstosend = newts;
+      }
       else
         tstosend = oldts;
 #endif /* TS5 */	
diff -ur ircd-hybrid-6/src/m_stats.c ircd-hybrid-6+stats/src/m_stats.c
--- ircd-hybrid-6/src/m_stats.c	Thu Aug 23 03:52:26 2001
+++ ircd-hybrid-6+stats/src/m_stats.c	Thu Aug 23 04:36:42 2001
@@ -25,6 +25,7 @@
 #include "m_commands.h"  /* m_pass prototype */
 #include "class.h"       /* report_classes */
 #include "client.h"      /* Client */
+#include "channel.h"
 #include "common.h"      /* TRUE/FALSE */
 #include "dline_conf.h"  /* report_dlines */
 #include "irc_string.h"  /* strncpy_irc */
@@ -37,6 +38,7 @@
 #include "scache.h"      /* list_scache */
 #include "send.h"        /* sendto_one */
 #include "s_bsd.h"       /* highest_fd */
+#include "struct.h"
 #include "s_conf.h"      /* ConfItem, report_configured_links */
 #include "s_debug.h"     /* send_usage */
 #include "s_misc.h"      /* serv_info */
@@ -125,6 +127,7 @@
  *            it--not reversed as in ircd.conf!
  */
 static const char* Lformat = ":%s %d %s %s %u %u %u %u %u :%u %u %s";
+static int report_channel_stats(struct Client *sptr);
 
 int m_stats(struct Client *cptr, struct Client *sptr, int parc, char *parv[])
 {
@@ -286,6 +289,17 @@
       valid_stats++;
       break;
 
+    case 'F': case 'f':
+      if(!IsAnOper(sptr))
+      {
+        sendto_one(sptr, form_str(ERR_NOPRIVILEGES), me.name, parv[0]);
+	break;
+      }
+
+      report_channel_stats(sptr);
+      valid_stats++;
+      break;
+      
     case 'G': case 'g' :
       if (!IsAnOper(sptr))
         {
@@ -562,4 +576,39 @@
 }
 
 
+static int report_channel_stats(struct Client *sptr)
+{
+  struct Channel *chptr;
+  int total_opless = 0;
+  int total = 0;
+  int opped;
+
+  for(chptr = channel; chptr; chptr = chptr->nextch)
+  {
+    struct SLink *m;
+    opped = 0;
+    
+    for (m = chptr->members; m; m = m->next)
+    {
+      if(m->flags & CHFL_CHANOP)
+      {
+        opped++;
+	break;
+      }
+    }
+
+    if(!opped)
+      total_opless++;
+
+    total++;
+  }
+
+  sendto_one(sptr, ":%s NOTICE %s :Total channels: %d.  Opless channels: %d. Hacked: %d.  Ignored: %d",
+             me.name, sptr->name, total, total_opless, total_hackops,
+	     total_ignoreops);
+
+  return 1;
+}
 
+    
+  
